==> elfcat-0.1.7.crate: elfcat-0.1.7/src/js/conceal.js <==
let prevShownTables = [];

function listOfParents(el) {
    let list = [el.id];

    while (el.tagName !== "HTML") {
        el = el.parentNode;

        list.unshift(el.id);
    }

    return list;
}

function hidePreviousTables() {
    for (let i = 0; i < prevShownTables.length; ++i) {
        prevShownTables[i].style.display = "none";
        prevShownTables[i].classList.remove("indirect");
    }
}

function showIfMatches(id, prefix, newPrefix, indirect = false) {
    if (!id.startsWith(prefix)) {
        return;
    }

    let tableId = id.replace(prefix, newPrefix);
    let table = document.getElementById(tableId);

    if (table === null) {
        return;
    }

    table.style.display = "block";

    if (indirect) {
        table.classList.add("indirect");
    } else {
        table.classList.remove("indirect");
    }

    prevShownTables.push(table);
}

document.addEventListener("mouseover", function (e) {
    let event = e || window.event;
    let target = event.target || event.srcElement;
    let parents = listOfParents(target);
    let cleared = false;
    const prefix = 'bin_';

    for (let i = 0; i < parents.length; i++) {
        let id = parents[i];

        if (!id.startsWith(prefix)) {
            continue;
        }

        if (!cleared) {
            cleared = true;
            hidePreviousTables();
        }

        showIfMatches(id, prefix, "info_");
        showIfMatches(id, "bin_segment", "info_phdr", true);
        showIfMatches(id, "bin_section", "info_shdr", true);
    }
}, false);

==> elfcat-0.1.8.crate: elfcat-0.1.8/src/js/conceal.js <==
let prevShownTables = [];

function getFirstClass(el) {
    let cls = el.classList[0];

    if (cls === undefined) {
        return "";
    } else {
        return cls;
    }
}

function listOfParents(el) {
    let list = [getFirstClass(el)];

    while (el.tagName !== "HTML") {
        el = el.parentNode;

        list.unshift(getFirstClass(el));
    }

    return list;
}

function hidePreviousTables() {
    for (let i = 0; i < prevShownTables.length; ++i) {
        prevShownTables[i].style.display = "none";
        prevShownTables[i].classList.remove("indirect");
    }
}

function showIfMatches(cl, prefix, newPrefix, indirect = false) {
    if (!cl.startsWith(prefix)) {
        return;
    }

    let tableId = cl.replace(prefix, newPrefix);
    let table = document.getElementById(tableId);

    if (table === null) {
        return;
    }

    table.style.display = "block";

    if (indirect) {
        table.classList.add("indirect");
    } else {
        table.classList.remove("indirect");
    }

    prevShownTables.push(table);
}

document.addEventListener("mouseover", function (e) {
    let event = e || window.event;
    let target = event.target || event.srcElement;
    let parents = listOfParents(target);
    let cleared = false;
    const prefix = 'bin_';

    for (let i = 0; i < parents.length; i++) {
        let cl = parents[i];

        if (!cl.startsWith(prefix)) {
            continue;
        }

        if (!cleared) {
            cleared = true;
            hidePreviousTables();
        }

        showIfMatches(cl, prefix, "info_");
        showIfMatches(cl, "bin_segment", "info_phdr", true);
        showIfMatches(cl, "bin_section", "info_shdr", true);
    }
}, false);
